@@ -8,23 +8,16 @@ from sentry.plugins.bases.notify import NotificationPlugin
 import sentry_dingding
 from .forms import DingDingOptionsForm
 
-from sentry.utils.compat import mock
-
-from sentry.models import Environment, Release, GroupInboxReason
-from sentry.models.groupinbox import add_group_to_inbox, remove_group_from_inbox
-from sentry.testutils import APITestCase, SnubaTestCase
-from sentry.testutils.helpers.datetime import before_now, iso_format
-
 DingTalk_API = "https://oapi.dingtalk.com/robot/send?access_token={token}"
 
 
-class DingDingPlugin(NotificationPlugin,APITestCase, SnubaTestCase):
+class DingDingPlugin(NotificationPlugin):
     """
     Sentry plugin to send error counts to DingDing.
     """
     author = 'dreamerldq'
     author_url = 'https://github.com/dreamerldq/sentry-dingding-format'
-    version = '1.0.18'
+    version = '1.0.19'
     description = 'Send project error counts to DingDing .'
     resource_links = [
         ('Source', 'https://github.com/dreamerldq/sentry-dingding-format'),
@@ -48,12 +41,9 @@ class DingDingPlugin(NotificationPlugin,APITestCase, SnubaTestCase):
         self.post_process(group, event, *args, **kwargs)
 
     def getGroupCount(self, groupId):
-        url = f"/api/0/issues/{groupId}/"
-        response = self.client.get(url, format="json")
-
-        assert response.status_code == 200
-        assert response.data["id"] == str(groupId)
-        return response.data["count"]
+        url = 'http://localhost:9000/api/0/issues/{groupId}/'.format(groupId=groupId )
+        r = requests.get(url).json()
+        return r["count"]
 
     def post_process(self, group, event, *args, **kwargs):
         """
@@ -67,8 +57,6 @@ class DingDingPlugin(NotificationPlugin,APITestCase, SnubaTestCase):
             return
 
         count = self.getGroupCount(group.id)
-        if(count>5):
-            return
 
         access_token = self.get_option('access_token', group.project)
         send_url = DingTalk_API.format(token=access_token)
